Index: src/factory.h |
diff --git a/src/factory.h b/src/factory.h |
index 840a8bb2c4fb9204d1c3388506581cb144823cdb..da161445b124baf2faf874d34ed6bf3e7de280d5 100644 |
--- a/src/factory.h |
+++ b/src/factory.h |
@@ -64,10 +64,9 @@ class Factory final { |
// Create a new PrototypeInfo struct. |
Handle<PrototypeInfo> NewPrototypeInfo(); |
- // Create a new SloppyBlockWithEvalContextExtension struct. |
- Handle<SloppyBlockWithEvalContextExtension> |
- NewSloppyBlockWithEvalContextExtension(Handle<ScopeInfo> scope_info, |
- Handle<JSObject> extension); |
+ // Create a new ContextExtension struct. |
+ Handle<ContextExtension> NewContextExtension(Handle<ScopeInfo> scope_info, |
+ Handle<Object> extension); |
// Create a pre-tenured empty AccessorPair. |
Handle<AccessorPair> NewAccessorPair(); |